Crate pallet_statement

Crate pallet_statement 

Supporting pallet for the statement store.

Overview

The Statement pallet provides means to create statements for the statement store.

This pallet contains an offchain worker that turns on-chain statement events into statements. These statements are placed in the store and propagated over the network.

Re-exports

pub use pallet::*;

Modules

pallet
The pallet module in each FRAME pallet hosts the most important items needed to construct this pallet.